@@ -9,7 +9,7 @@ class Timer:
 
     def get_time(self):
 
-        time_end = tm.time() - self.time_start
+        time_total = tm.time() - self.time_start
 
-        return time_end
+        return time_total
 
