@@ -17,10 +17,6 @@ from . import array as cc_array
 from . import maths as cc_maths
 from . import combinations as cc_combinations
 from .strings import format_float_to_str as cc_strings_format_float_to_str
-# import ccalafiore.array
-# import ccalafiore.maths
-# import ccalafiore.combinations
-# import ccalafiore.strings
 
 
 class Time:
@@ -210,7 +206,7 @@ class Loader:
             self.combinations_directories[:, self.time.level] += self.time.shift
 
 
-def train_early_stop(model, loader, criterion, optimizer, scheduler, I=50):
+def train_early_stop(model, loader, criterion, optimizer, scheduler, I=10):
 
     # timer = cc_clock.Timer()
     datetime_start = datetime.datetime.today()
@@ -276,19 +272,18 @@ def train_early_stop(model, loader, criterion, optimizer, scheduler, I=50):
 
             torch.set_grad_enabled(False)
 
-            # statistics
-            loss_float_eb = loss_eb.item()
+            # # statistics
+            # loss_float_eb = loss_eb.item()
+            # # noinspection PyTypeChecker
+            # corrects_eb = torch.sum(preds == labels_eb).item()
+            # acc_eb = corrects_eb / batch_eb.shape[0]
+            # loss_str_eb = cc_strings_format_float_to_str(loss_float_eb, n_decimals=n_decimals_for_printing)
+            # acc_str_eb = cc_strings_format_float_to_str(acc_eb, n_decimals=n_decimals_for_printing)
+            # print('Training. Epoch: {:d}. Batch {:d}. Loss: {:s}. Acc: {:s}.'.format(e, b, loss_str_eb, acc_str_eb))
+
+            running_loss_e += loss_eb.item() * batch_eb.shape[0]
             # noinspection PyTypeChecker
-            corrects_eb = torch.sum(preds == labels_eb).item()
-            acc_eb = corrects_eb / batch_eb.shape[0]
-
-            loss_str_eb = cc_strings_format_float_to_str(loss_float_eb, n_decimals=n_decimals_for_printing)
-            acc_str_eb = cc_strings_format_float_to_str(acc_eb, n_decimals=n_decimals_for_printing)
-
-            print('Training. Epoch: {:d}. Batch {:d}. Loss: {:s}. Acc: {:s}.'.format(e, b, loss_str_eb, acc_str_eb))
-
-            running_loss_e += loss_float_eb * batch_eb.shape[0]
-            running_corrects_e += corrects_eb
+            running_corrects_e += torch.sum(preds == labels_eb).item()
 
             b += 1
 
@@ -302,7 +297,6 @@ def train_early_stop(model, loader, criterion, optimizer, scheduler, I=50):
         loss_str_e = cc_strings_format_float_to_str(loss_e, n_decimals=n_decimals_for_printing)
         acc_str_e = cc_strings_format_float_to_str(acc_e, n_decimals=n_decimals_for_printing)
 
-        print()
         print('Training. Epoch: {:d}. Loss: {:s}. Acc: {:s}. Best Acc: {:s}.'.format(
             e, loss_str_e, acc_str_e, best_acc_str))
 
@@ -332,19 +326,18 @@ def train_early_stop(model, loader, criterion, optimizer, scheduler, I=50):
             _, preds = torch.max(outputs, 1)
             loss_eb = criterion(outputs, labels_eb)
 
-            # statistics
-            loss_float_eb = loss_eb.item()
+            # # statistics
+            # loss_float_eb = loss_eb.item()
+            # # noinspection PyTypeChecker
+            # corrects_eb = torch.sum(preds == labels_eb).item()
+            # acc_eb = corrects_eb / batch_eb.shape[0]
+            # loss_str_eb = cc_strings_format_float_to_str(loss_float_eb, n_decimals=n_decimals_for_printing)
+            # acc_str_eb = cc_strings_format_float_to_str(acc_eb, n_decimals=n_decimals_for_printing)
+            # print('Validation. Epoch: {:d}. Batch {:d}. Loss: {:s}. Acc: {:s}.'.format(e, b, loss_str_eb, acc_str_eb))
+
+            running_loss_e += loss_eb.item() * batch_eb.shape[0]
             # noinspection PyTypeChecker
-            corrects_eb = torch.sum(preds == labels_eb).item()
-            acc_eb = corrects_eb / batch_eb.shape[0]
-
-            loss_str_eb = cc_strings_format_float_to_str(loss_float_eb, n_decimals=n_decimals_for_printing)
-            acc_str_eb = cc_strings_format_float_to_str(acc_eb, n_decimals=n_decimals_for_printing)
-
-            print('Validation. Epoch: {:d}. Batch {:d}. Loss: {:s}. Acc: {:s}.'.format(e, b, loss_str_eb, acc_str_eb))
-
-            running_loss_e += loss_float_eb * batch_eb.shape[0]
-            running_corrects_e += corrects_eb
+            running_corrects_e += torch.sum(preds == labels_eb).item()
 
             b += 1
 
@@ -356,7 +349,6 @@ def train_early_stop(model, loader, criterion, optimizer, scheduler, I=50):
         loss_str_e = cc_strings_format_float_to_str(loss_e, n_decimals=n_decimals_for_printing)
         acc_str_e = cc_strings_format_float_to_str(acc_e, n_decimals=n_decimals_for_printing)
 
-        print()
         print('Validation. Epoch: {:d}. Loss: {:s}. Acc: {:s}. Best Acc: {:s}.'.format(
             e, loss_str_e, acc_str_e, best_acc_str))
 
@@ -404,7 +396,7 @@ def train_early_stop(model, loader, criterion, optimizer, scheduler, I=50):
     return model, stats
 
 
-def train_early_stop_old(model, loader, criterion, optimizer, scheduler, I=50):
+def train_early_stop_old(model, loader, criterion, optimizer, scheduler, I=10):
 
     # timer = cc_clock.Timer()
     datetime_start = datetime.datetime.today()
